@@ -29,10 +29,11 @@
 # ===================================================================
 
 import unittest
+from binascii import unhexlify
 
 from Cryptodome.SelfTest.loader import load_tests
 from Cryptodome.SelfTest.st_common import list_test_cases
-from Cryptodome.Util.py3compat import tobytes, b, unhexlify
+from Cryptodome.Util.py3compat import tobytes, is_string
 from Cryptodome.Cipher import AES, DES3, DES
 from Cryptodome.Hash import SHAKE128
 
@@ -50,34 +51,34 @@ class CfbTests(BlockChainingTests):
     # Redefine test_unaligned_data_128/64
 
     def test_unaligned_data_128(self):
-        plaintexts = [ b("7777777") ] * 100
+        plaintexts = [ b"7777777" ] * 100
 
         cipher = AES.new(self.key_128, AES.MODE_CFB, self.iv_128, segment_size=8)
         ciphertexts = [ cipher.encrypt(x) for x in plaintexts ]
         cipher = AES.new(self.key_128, AES.MODE_CFB, self.iv_128, segment_size=8)
-        self.assertEqual(b("").join(ciphertexts), cipher.encrypt(b("").join(plaintexts)))
+        self.assertEqual(b"".join(ciphertexts), cipher.encrypt(b"".join(plaintexts)))
 
         cipher = AES.new(self.key_128, AES.MODE_CFB, self.iv_128, segment_size=128)
         ciphertexts = [ cipher.encrypt(x) for x in plaintexts ]
         cipher = AES.new(self.key_128, AES.MODE_CFB, self.iv_128, segment_size=128)
-        self.assertEqual(b("").join(ciphertexts), cipher.encrypt(b("").join(plaintexts)))
+        self.assertEqual(b"".join(ciphertexts), cipher.encrypt(b"".join(plaintexts)))
 
     def test_unaligned_data_64(self):
-        plaintexts = [ b("7777777") ] * 100
+        plaintexts = [ b"7777777" ] * 100
         cipher = DES3.new(self.key_192, DES3.MODE_CFB, self.iv_64, segment_size=8)
         ciphertexts = [ cipher.encrypt(x) for x in plaintexts ]
         cipher = DES3.new(self.key_192, DES3.MODE_CFB, self.iv_64, segment_size=8)
-        self.assertEqual(b("").join(ciphertexts), cipher.encrypt(b("").join(plaintexts)))
+        self.assertEqual(b"".join(ciphertexts), cipher.encrypt(b"".join(plaintexts)))
 
         cipher = DES3.new(self.key_192, DES3.MODE_CFB, self.iv_64, segment_size=64)
         ciphertexts = [ cipher.encrypt(x) for x in plaintexts ]
         cipher = DES3.new(self.key_192, DES3.MODE_CFB, self.iv_64, segment_size=64)
-        self.assertEqual(b("").join(ciphertexts), cipher.encrypt(b("").join(plaintexts)))
+        self.assertEqual(b"".join(ciphertexts), cipher.encrypt(b"".join(plaintexts)))
 
     # Extra
 
     def test_segment_size_128(self):
-        for bits in xrange(8, 129, 8):
+        for bits in range(8, 129, 8):
             cipher = AES.new(self.key_128, AES.MODE_CFB, self.iv_128,
                              segment_size=bits)
 
@@ -87,7 +88,7 @@ class CfbTests(BlockChainingTests):
                               segment_size=bits)
 
     def test_segment_size_64(self):
-        for bits in xrange(8, 65, 8):
+        for bits in range(8, 65, 8):
             cipher = DES3.new(self.key_192, DES3.MODE_CFB, self.iv_64,
                               segment_size=bits)
 
@@ -110,7 +111,7 @@ class NistCfbVectors(unittest.TestCase):
         for tv in test_vectors:
 
             # The test vector file contains some directive lines
-            if isinstance(tv, basestring):
+            if is_string(tv):
                 direction = tv
                 continue
 
@@ -137,7 +138,7 @@ class NistCfbVectors(unittest.TestCase):
         for tv in test_vectors:
 
             # The test vector file contains some directive lines
-            if isinstance(tv, basestring):
+            if is_string(tv):
                 direction = tv
                 continue
 
@@ -160,13 +161,13 @@ class NistCfbVectors(unittest.TestCase):
 
             if direction == '[ENCRYPT]':
                 cts = []
-                for j in xrange(1000):
+                for j in range(1000):
                     plaintext = get_input(tv.plaintext, cts, j)
                     cts.append(cipher.encrypt(plaintext))
                 self.assertEqual(cts[-1], tv.ciphertext)
             elif direction == '[DECRYPT]':
                 pts = []
-                for j in xrange(1000):
+                for j in range(1000):
                     ciphertext = get_input(tv.ciphertext, pts, j)
                     pts.append(cipher.decrypt(ciphertext))
                 self.assertEqual(pts[-1], tv.plaintext)
@@ -184,7 +185,7 @@ class NistCfbVectors(unittest.TestCase):
         for tv in test_vectors:
 
             # The test vector file contains some directive lines
-            if isinstance(tv, basestring):
+            if is_string(tv):
                 direction = tv
                 continue
 
